@@ -48,7 +48,7 @@ status_map = {
 ## Expose urls
 #
 
-def expose(url_pattern, method=None, content_type='text/html', charset='UTF-8'):
+def expose(url_pattern, method='GET', content_type='text/html', charset='UTF-8'):
     """ Expose this function to the world, matching the given URL pattern and, optionally, HTTP method, ContentType and Charset.
     """
     def entangle(func):
@@ -56,6 +56,7 @@ def expose(url_pattern, method=None, content_type='text/html', charset='UTF-8'):
         def wrapped(env, start_response):
             status  = 200
             headers = [('Content-type', '%s; charset=%s' % (content_type, charset))]
+            params(env, method)
             resp    = func(env)
 
             if type(resp) == tuple:
@@ -66,11 +67,26 @@ def expose(url_pattern, method=None, content_type='text/html', charset='UTF-8'):
                     headers.append((h,heads[h]))
 
             start_response(status_map[status], headers)
-
             return [resp]
-
     return entangle
 
+## Grab the params
+#
+
+def params(env, method):
+    data = None
+    params = {}
+    if method == 'GET':
+        data = env['QUERY_STRING']
+    elif method == 'POST':
+        data = env['wsgi.input'].read()
+    if data != None and data != '':
+        for keyval in data.split('&'):
+            k,v = keyval.split('=')
+            params[k] = v
+    env['params'] = params
+
+
 ## Make the application
 #
 
